@@ -6,7 +6,7 @@
 
 
 
-#' Extract accessory tables and summaries from a local NASIS Database
+#' Get accessory tables and summaries from a local NASIS Database
 #'
 #' @param SS get data from the currently loaded Selected Set in NASIS or from
 #' the entire local database (default: `TRUE`)
@@ -238,8 +238,7 @@ LEFT OUTER JOIN (
                        recwlupdated, recuseriidref, phhuartiid
                        FROM (
                        SELECT DISTINCT phiid FROM phorizon_View_1
-                       ) as p LEFT OUTER JOIN phhuarts ", ifelse(SS, "_View_1","") ,
-                       " ON p.phiid = phiidref;")
+                       ) as p LEFT OUTER JOIN phhuarts_View_1 ON p.phiid = phiidref;")
   if (SS == FALSE) {
     q.art.data <- gsub(pattern = '_View_1', replacement = '', x = q.art.data, fixed = TRUE)
   }
@@ -484,14 +483,15 @@ LEFT OUTER JOIN (
 	  ncharpath <- nchar(d.photolink$imagepath)
 
 	  # windows max path length is 260 (unless overridden in registry?)
-	  if (any(ncharpath > 260))
+	  if (any(ncharpath > 260, na.rm = TRUE)) {
 	    warning("some image paths are too long (>260 characters) for basename()")
 
-	  bad.idx <- which(ncharpath > 260)
-	  d.photolink$imagepath[bad.idx] <- substr(d.photolink$imagepath[bad.idx],
-	                                           start = ncharpath[bad.idx] - 260,
-	                                           stop = ncharpath[bad.idx])
-	  d.photolink$imagename <- try(basename(d.photolink$imagepath))
+  	  bad.idx <- which(ncharpath > 260)
+  	  d.photolink$imagepath[bad.idx] <- substr(d.photolink$imagepath[bad.idx],
+  	                                           start = ncharpath[bad.idx] - 260,
+  	                                           stop = ncharpath[bad.idx])
+  	  d.photolink$imagename <- try(basename(d.photolink$imagepath))
+	  }
 	}
 
 	d.rf.summary <- simplifyFragmentData(d.rf.data, id.var='phiid', nullFragsAreZero = nullFragsAreZero)
